remind_me: remind_me

Description Usage Value

View source: R/remind_me.R

Description

Provides information about the exam for the course "Programming in Psychological Science"

Usage

1

Value

A list containing the date and the mode of the exam as well as the teacher names.


emilycampossindermann/hiddenInfo documentation built on Jan. 29, 2022, 12:47 a.m.