Provides information about the exam for the course "Programming in Psychological Science"
1 |
A list containing the date and the mode of the exam as well as the teacher names.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.